@@ -82,13 +82,24 @@ class BlockStorage(service.UnifiedService):
             multiattach=multiattach, backup_id=backup_id)
 
     @service.should_be_overridden
-    def list_volumes(self, detailed=True):
+    def list_volumes(self, detailed=True, search_opts=None, marker=None,
+                     limit=None, sort_key=None, sort_dir=None, sort=None):
         """Lists all volumes.
 
         :param detailed: Whether to return detailed volume info.
+        :param search_opts: Search options to filter out volumes.
+        :param marker: Begin returning volumes that appear later in the volume
+                       list than that represented by this volume id.
+        :param limit: Maximum number of volumes to return.
+        :param sort_key: Key to be sorted; deprecated in kilo
+        :param sort_dir: Sort direction, should be 'desc' or 'asc'; deprecated
+                         in kilo
+        :param sort: Sort information
         :returns: Return volumes list.
         """
-        return self._impl.list_volumes(detailed=detailed)
+        return self._impl.list_volumes(
+            detailed=detailed, search_opts=search_opts, marker=marker,
+            limit=limit, sort_key=sort_key, sort_dir=sort_dir, sort=sort)
 
     @service.should_be_overridden
     def get_volume(self, volume_id):
