@@ -23,8 +23,9 @@ import subprocess
 import sys
 import uuid
 
+import jinja2
+
 from rally import api
-from rally.ui import utils
 
 LOG = logging.getLogger("verify-job")
 LOG.setLevel(logging.DEBUG)
@@ -55,7 +56,8 @@ class Step(object):
         self.args = args
         self.rapi = rapi
         self.result = {"status": Status.PASS,
-                       "doc": self.__doc__}
+                       "doc": self.__doc__,
+                       "cmd": "None command found"}
 
     @property
     def name(self):
@@ -114,10 +116,12 @@ class Step(object):
     def _write_file(cls, path, data, compress=False):
         """Create a file and write some data to it."""
         if compress:
-            with gzip.open(path, "wb") as f:
+            with gzip.open(path, "w") as f:
+                if not isinstance(data, bytes):
+                    data = data.encode()
                 f.write(data)
         else:
-            with open(path, "wb") as f:
+            with open(path, "w") as f:
                 f.write(data)
         return path
 
@@ -127,7 +131,7 @@ class Step(object):
         try:
             LOG.info("Start `%s` command." % command)
             stdout = subprocess.check_output(command.split(),
-                                             stderr=subprocess.STDOUT)
+                                             stderr=subprocess.STDOUT).decode()
         except subprocess.CalledProcessError as e:
             LOG.error("Command `%s` failed." % command)
             return Status.ERROR, e.output
@@ -141,7 +145,7 @@ class Step(object):
 class SetUpStep(Step):
     """Validate deployment, create required resources and directories."""
 
-    DEPLOYMENT_NAME = "devstack"
+    DEPLOYMENT_NAME = "tempest"
 
     def run(self):
         if not os.path.exists("%s/extra" % self.BASE_DIR):
@@ -229,7 +233,7 @@ class CreateVerifier(Step):
     DEPENDS_ON = ListPlugins
     CALL_ARGS = {"type": "tempest",
                  "name": "my-verifier",
-                 "source": "https://git.openstack.org/openstack/tempest"}
+                 "source": "https://opendev.org/openstack/tempest"}
 
 
 class ShowVerifier(Step):
@@ -261,7 +265,7 @@ class UpdateVerifier(Step):
         # Get the penultimate verifier commit ID
         p_commit_id = subprocess.check_output(
             ["git", "log", "-n", "1", "--pretty=format:%H"],
-            cwd=verifications_dir).strip()
+            cwd=verifications_dir).decode().strip()
         self.CALL_ARGS = {"version": p_commit_id}
 
 
@@ -277,7 +281,7 @@ class ExtendVerifier(Step):
 
     COMMAND = "verify add-verifier-ext --source %(source)s"
     DEPENDS_ON = CreateVerifier
-    CALL_ARGS = {"source": "https://git.openstack.org/openstack/"
+    CALL_ARGS = {"source": "https://opendev.org/openstack/"
                            "keystone-tempest-plugin"}
 
 
@@ -493,6 +497,16 @@ def run(args):
     return results.values()
 
 
+def create_report(results):
+    template_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)),
+                                "pages")
+    loader = jinja2.FileSystemLoader(template_dir)
+    env = jinja2.Environment(loader=loader)
+    template = env.get_template("verify-index.html")
+    with open(os.path.join(Step.BASE_DIR, "extra/index.html"), "w") as f:
+        f.write(template.render(steps=results))
+
+
 def main():
     parser = argparse.ArgumentParser(description="Launch rally-verify job.")
     parser.add_argument("--mode", type=str, default="light",
@@ -514,9 +528,7 @@ def main():
     steps = run(args)
     results = [step.to_html() for step in steps]
 
-    template = utils.get_template("ci/index_verify.html")
-    with open(os.path.join(Step.BASE_DIR, "extra/index.html"), "w") as f:
-        f.write(template.render(steps=results))
+    create_report(results)
 
     if len([None for step in steps
             if step.result["status"] == Status.PASS]) == len(steps):
